API Reference
=============

xlrd
----

.. automodule:: xlrd
   :members:

xlrd.biffh
----------

.. automodule:: xlrd.biffh
   :members:

xlrd.book
---------

.. automodule:: xlrd.book
   :members:

xlrd.compdoc
------------

.. automodule:: xlrd.compdoc
   :members:

xlrd.formatting
---------------

.. automodule:: xlrd.formatting
   :members:

xlrd.formula
-------------

.. automodule:: xlrd.formula
   :members:

xlrd.sheet
----------

.. currentmodule:: xlrd.sheet

.. autoclass:: xlrd.sheet.Sheet
   :members:
   :exclude-members: gcw, col

   .. method:: col(colx)

     Returns a sequence of the :class:`Cell` objects in the given column.

   .. autoattribute:: xlrd.sheet.Sheet.gcw
      :annotation:


.. automodule:: xlrd.sheet
   :members:
   :exclude-members: Sheet

xlrd.xldate
-----------

.. currentmodule:: xlrd.xldate

.. automodule:: xlrd.xldate
   :members:
